Verifier

Struct Verifier 

pub struct Verifier<F, H>
where F: BinaryField, H: HashSuite,
{ /* private fields */ }
Struct for verifying instances of a particular constraint system.

The Self::setup constructor determines public parameters for proving instances of the given constraint system. Then Self::verify is called one or more times with individual instances.

Implementations

Source

impl<F, H> Verifier<F, H>
where F: BinaryField, H: HashSuite, Output<H::LeafHash>: DeserializeBytes,

pub fn setup( constraint_system: ConstraintSystem<F>, log_inv_rate: usize, ) -> Result<Self, Error>

Constructs a verifier for a constraint system.

See Verifier struct documentation for details.

pub const fn iop_verifier(&self) -> &IOPVerifier<F>

Returns a reference to the IOP verifier.

pub const fn constraint_system(&self) -> &ConstraintSystemPadded<F>

pub const fn iop_compiler(&self) -> &BaseFoldVerifierCompiler<F>

Returns a reference to the BaseFold ZK verifier compiler.

pub fn verify<Challenger_: Challenger>( &self, public: &[F], transcript: &mut VerifierTranscript<Challenger_>, ) -> Result<(), Error>

Verifies a proof against the constraint system.

Arguments
  • public - The public inputs to the constraint system
  • transcript - The verifier transcript for Fiat-Shamir
Preconditions
  • The public input length must match the constraint system’s public input size