pub struct Verifier<F, H>where
F: BinaryField,
H: HashSuite,{ /* private fields */ }Expand description
Struct for verifying instances of a particular constraint system.
The Self::setup constructor determines public parameters for proving instances of the given
constraint system. Then Self::verify is called one or more times with individual instances.
Implementations
Sourceimpl<F, H> Verifier<F, H>
impl<F, H> Verifier<F, H>
Sourcepub fn setup(
constraint_system: ConstraintSystem<F>,
log_inv_rate: usize,
) -> Result<Self, Error>
pub fn setup( constraint_system: ConstraintSystem<F>, log_inv_rate: usize, ) -> Result<Self, Error>
Constructs a verifier for a constraint system.
See Verifier struct documentation for details.
Sourcepub const fn iop_verifier(&self) -> &IOPVerifier<F>
pub const fn iop_verifier(&self) -> &IOPVerifier<F>
Returns a reference to the IOP verifier.
pub const fn constraint_system(&self) -> &ConstraintSystemPadded<F>
Sourcepub const fn iop_compiler(&self) -> &BaseFoldVerifierCompiler<F>
pub const fn iop_compiler(&self) -> &BaseFoldVerifierCompiler<F>
Returns a reference to the BaseFold ZK verifier compiler.
Sourcepub fn verify<Challenger_: Challenger>(
&self,
public: &[F],
transcript: &mut VerifierTranscript<Challenger_>,
) -> Result<(), Error>
pub fn verify<Challenger_: Challenger>( &self, public: &[F], transcript: &mut VerifierTranscript<Challenger_>, ) -> Result<(), Error>